@@ -34,7 +34,7 @@ return(fit)
 function(angle,x,period,opti) {
 response <- x
 n.var <- dim(x)[2] 
-fit <- matrix(NA,nrow=n.var,ncol=2)
+fit <- matrix(NaN,nrow=n.var,ncol=2)
 for (i in 1:n.var) {
 if(opti) {fits <- optimize(f=phaser,c(0,24),time=angle,response=x[,i],period=period,maximum=TRUE)  #iterative fit 
 fit[i,1] <- fits$maximum
