@@ -328,12 +328,12 @@ function(r,nfactors=1,n.obs = NA,rotate="oblimin",scores="tenBerge",residuals=FA
     if(rotate != "none") {if (nfactors > 1) {
 
     
-   	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor" | rotate =="targetT" |rotate =="TargetT" ) { 
+   	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor" | rotate =="targetT" |rotate =="TargetT" |rotate =="equamax" | rotate =="varimin" |rotate =="specialT" ) { 
    	if (!require(GPArotation)) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
    			rotated <- do.call(rotate,list(loadings,...))
    			loadings <- rotated$loadings
-   			 Phi <- NULL} else { 
+   			Phi <- NULL} else { 
    			
      			if ((rotate=="promax")|(rotate=="Promax") ) {pro <- Promax(loadings)
      			                loadings <- pro$loadings
@@ -343,7 +343,7 @@ function(r,nfactors=1,n.obs = NA,rotate="oblimin",scores="tenBerge",residuals=FA
      			              	loadings <- pro$loadings
      			                Phi <- pro$Phi} else {
      			                     
-     			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ" |rotate == "biquartimin" |rotate == "targetQ" |rotate == "TargetQ" ) {
+     			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ" |rotate == "biquartimin" |rotate == "targetQ" |rotate == "TargetQ"  |rotate =="specialQ" ) {
      				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
      				Phi <- NULL} else { ob  <- try(do.call(rotate,list(loadings,...) ))
      				          if(class(ob)== as.character("try-error"))  {warning("The requested transformaton failed, Promax was used instead as an oblique transformation")
