@@ -1,16 +1,18 @@
- #developed July 4, 2012
- #some ideas taken from Bliese multilevel package (specifically, the WABA results)
-   "statsBy" <-
-   function (data,group,cors=FALSE,method="pearson") { #  
+#developed July 4, 2012
+#modified July 9, 2014 to allow polychorics within groups
+#some ideas taken from Bliese multilevel package (specifically, the WABA results)
+"statsBy" <-
+   function (data,group,cors=FALSE,method="pearson",poly=FALSE) { #  
     cl <- match.call()
   valid <- function(x) { #count the number of valid cases 
         sum(!is.na(x))
     }
+#defing a function to count pairwise observations
   pairwise <- function(x) {n <- t(!is.na(x)) %*% (!is.na(x))
               n}
-       gr <- which(colnames(data) %in% group)
-       
-       z1 <- data[,group]
+#get the grouping information           
+gr <- which(colnames(data) %in% group)      
+z1 <- data[,group]
        z <- z1
        cnames <- colnames(data)
        for (i in 1:ncol(data)) {if(is.factor(data[,i]) || is.logical(data[,i])) {
@@ -18,11 +20,12 @@
             # colnames(data)[i] <- paste(cnames[i],"*",sep="")
              }}
        xvals <- list()
+       #find the statistics by group
                temp <- by(data,z,colMeans,na.rm=TRUE)
                
                rownn <- lapply(temp,is.null)
                if(sum(as.integer(rownn)) > 0) {
-               rown <-  names(temp)[-which(rownn==TRUE)] } else {rown <- names(temp) }              
+              	 rown <-  names(temp)[-which(rownn==TRUE)] } else {rown <- names(temp) }              
                xvals$mean <- t(matrix(unlist(temp),nrow=ncol(data)))              
                xvals$sd <-t(matrix(unlist(by(data,z,function(x) sapply(x,sd,na.rm=TRUE))),nrow=ncol(data)))
                xvals$n <- t(matrix(unlist(by(data,z,function(x) sapply(x,valid))),nrow=ncol(data)))
@@ -37,26 +40,25 @@
                MSw <- colSums(xvals$sd^2*(xvals$n-1))/(colSums(xvals$n-1)) #find the pooled sd
                xvals$F <- MSb/MSw
                N <- colSums(xvals$n)
-              # npr <-(N^2 - colSums(xvals$n))/(N *(nrow(xvals$n) -1))
-              # npr <- harmonic.mean(xvals$n-1)
+             
               npr <- (colSums(xvals$n-1)+nrow(xvals$n))/(nrow(xvals$n))
                xvals$ICC1 <- (MSb-MSw)/(MSb + MSw*(npr-1))
                xvals$ICC2 <- (MSb-MSw)/(MSb)
-               
-             if(cors) { r <- by(data,z,function(x) cor(x[-gr],use="pairwise",method=method))
+    #if we want within group correlations, then find them  
+             if(cors) {if(!poly) { r <- by(data,z,function(x) cor(x[-gr],use="pairwise",method=method)) } else { r <- by(data,z,function(x) polychoric(x[-gr])$rho)}
+                 
               nvars <-  ncol(r[[1]])
-              xvals$r <- r
+              xvals$r <- r   #store them as square matrices
               lower <- lapply(r,function(x) x[lower.tri(x)])
-             
-             xvals$within <- t(matrix(unlist(lower),nrow=nvars*(nvars-1)/2))
+              xvals$within <- t(matrix(unlist(lower),nrow=nvars*(nvars-1)/2))  #string them out as well
              
               cnR <- abbreviate(cnames[-gr],minlength=5) 
              
       k <- 1
        colnames(xvals$within) <- paste("V",1:ncol(xvals$within))
       for(i in 1:(nvars-1)) {for (j in (i+1):nvars) {
-      colnames(xvals$within)[k] <- paste(cnR[i],cnR[j],sep="-")
-      k<- k +1 }}
+      	colnames(xvals$within)[k] <- paste(cnR[i],cnR[j],sep="-")
+     	 k<- k +1 }} 
              
              wt <- by(data,z,function(x) count.pairwise(x[-gr]))
              lower.wt <- t(matrix(unlist(lapply(wt,function(x) x[lower.tri(x)])    )  ,nrow=nvars*(nvars-1)/2))
@@ -74,7 +76,7 @@
               }
 
               nvar <- ncol(data)-length(group) #we have dropped the grouping variable
-               xvals$raw <- cor(data,use="pairwise")
+               if(!poly) {xvals$raw <- cor(data,use="pairwise",method=method)} else {xvals$raw <- polychoric(data)$rho}
              new.data <- as.matrix( merge(xvals$mean,data,by=group,suffixes =c(".bg",""))) #drop the grouping variable(s) 
              new.data <- new.data[,(length(group)+1):ncol(new.data)]
              
