@@ -1,7 +1,7 @@
 ### R code from vignette source 'overview.Rnw'
 
 ###################################################
-### code chunk number 1: overview.Rnw:325-328
+### code chunk number 1: overview.Rnw:334-337
 ###################################################
 library(psych)
 data(sat.act) 
@@ -9,14 +9,14 @@ describe(sat.act)  #basic descriptive statistics
 
 
 ###################################################
-### code chunk number 2: overview.Rnw:335-337
+### code chunk number 2: overview.Rnw:344-346
 ###################################################
  #basic descriptive statistics by a grouping variable.
 describeBy(sat.act,sat.act$gender,skew=FALSE,ranges=FALSE)
 
 
 ###################################################
-### code chunk number 3: overview.Rnw:345-348
+### code chunk number 3: overview.Rnw:354-357
 ###################################################
 sa.mat <- describeBy(sat.act,list(sat.act$gender,sat.act$education),
  skew=FALSE,ranges=FALSE,mat=TRUE)
@@ -24,7 +24,15 @@ headTail(sa.mat)
 
 
 ###################################################
-### code chunk number 4: overview.Rnw:359-363
+### code chunk number 4: outlier
+###################################################
+png( 'outlier.png' )
+d2 <- outlier(sat.act,cex=.8)
+dev.off()
+
+
+###################################################
+### code chunk number 5: overview.Rnw:388-392
 ###################################################
 x <- matrix(1:120,ncol=10,byrow=TRUE)
 colnames(x) <- paste('V',1:10,sep='')
@@ -33,15 +41,16 @@ new.x
 
 
 ###################################################
-### code chunk number 5: pairspanels
+### code chunk number 6: pairspanels
 ###################################################
 png( 'pairspanels.png' )
-pairs.panels(sat.act,pch='.')
+sat.d2 <- data.frame(sat.act,d2) #combine the d2 statistics from before with the sat.act data.frame
+pairs.panels(sat.d2,bg=c("yellow","blue")[(d2 > 25)+1],pch=21)
 dev.off()
 
 
 ###################################################
-### code chunk number 6: affect
+### code chunk number 7: affect
 ###################################################
 png('affect.png')
 pairs.panels(affect[14:17],bg=c("red","black","white","blue")[affect$Film],pch=21,
@@ -50,28 +59,28 @@ dev.off()
 
 
 ###################################################
-### code chunk number 7: overview.Rnw:422-424
+### code chunk number 8: overview.Rnw:452-454
 ###################################################
 data(sat.act)
 violinBy(sat.act[5:6],sat.act$gender,grp.name=c("M", "F"),main="Density Plot by gender for SAT V and Q")
 
 
 ###################################################
-### code chunk number 8: overview.Rnw:449-451
+### code chunk number 9: overview.Rnw:479-481
 ###################################################
 data(epi.bfi)
 error.bars.by(epi.bfi[,6:10],epi.bfi$epilie<4)
 
 
 ###################################################
-### code chunk number 9: overview.Rnw:464-466
+### code chunk number 10: overview.Rnw:494-496
 ###################################################
 error.bars.by(sat.act[5:6],sat.act$gender,bars=TRUE,
         labels=c("Male","Female"),ylab="SAT score",xlab="")
 
 
 ###################################################
-### code chunk number 10: overview.Rnw:482-491
+### code chunk number 11: overview.Rnw:512-521
 ###################################################
 op <- par(mfrow=c(1,2))
   data(affect)
@@ -85,20 +94,20 @@ op <- par(mfrow=c(1,1))
 
 
 ###################################################
-### code chunk number 11: overview.Rnw:505-507
+### code chunk number 12: overview.Rnw:535-537
 ###################################################
 data(bfi)
 with(bfi,{bi.bars(age,gender,ylab="Age",main="Age by males and females")})
 
 
 ###################################################
-### code chunk number 12: overview.Rnw:521-522
+### code chunk number 13: overview.Rnw:551-552
 ###################################################
 lowerCor(sat.act)
 
 
 ###################################################
-### code chunk number 13: overview.Rnw:529-535
+### code chunk number 14: overview.Rnw:559-565
 ###################################################
 female <- subset(sat.act,sat.act$gender==2)
  male <- subset(sat.act,sat.act$gender==1)
@@ -109,14 +118,14 @@ round(both,2)
 
 
 ###################################################
-### code chunk number 14: overview.Rnw:541-543
+### code chunk number 15: overview.Rnw:571-573
 ###################################################
 diffs <-  lowerUpper(lower,upper,diff=TRUE)
 round(diffs,2)
 
 
 ###################################################
-### code chunk number 15: corplot.png
+### code chunk number 16: corplot.png
 ###################################################
 png('corplot.png')
 cor.plot(Thurstone,numbers=TRUE,main="9 cognitive variables from Thurstone")
@@ -124,7 +133,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 16: circplot.png
+### code chunk number 17: circplot.png
 ###################################################
 png('circplot.png')
 circ <- sim.circ(24)
@@ -134,7 +143,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 17: spider.png
+### code chunk number 18: spider.png
 ###################################################
 png('spider.png')
 op<- par(mfrow=c(2,2))
@@ -144,69 +153,75 @@ dev.off()
 
 
 ###################################################
-### code chunk number 18: overview.Rnw:610-611
+### code chunk number 19: overview.Rnw:640-641
 ###################################################
 corr.test(sat.act)
 
 
 ###################################################
-### code chunk number 19: overview.Rnw:622-623
+### code chunk number 20: overview.Rnw:652-653
 ###################################################
 r.test(50,.3)
 
 
 ###################################################
-### code chunk number 20: overview.Rnw:629-630
+### code chunk number 21: overview.Rnw:659-660
 ###################################################
 r.test(30,.4,.6)
 
 
 ###################################################
-### code chunk number 21: overview.Rnw:637-638
+### code chunk number 22: overview.Rnw:667-668
 ###################################################
 r.test(103,.4,.5,.1)
 
 
 ###################################################
-### code chunk number 22: overview.Rnw:644-645
+### code chunk number 23: overview.Rnw:674-675
 ###################################################
 r.test(103,.5,.6,.7,.5,.5,.8)  #steiger Case B 
 
 
 ###################################################
-### code chunk number 23: overview.Rnw:653-654
+### code chunk number 24: overview.Rnw:683-684
 ###################################################
 cortest(sat.act)
 
 
 ###################################################
-### code chunk number 24: overview.Rnw:665-666
+### code chunk number 25: overview.Rnw:695-696
 ###################################################
 draw.tetra()
 
 
 ###################################################
-### code chunk number 25: overview.Rnw:685-686
+### code chunk number 26: overview.Rnw:707-708
+###################################################
+draw.cor(expand=20,cuts=c(0,0))
+
+
+###################################################
+### code chunk number 27: overview.Rnw:728-729
 ###################################################
 set.cor(y = 5:9,x=1:4,data=Thurstone)
 
 
 ###################################################
-### code chunk number 26: overview.Rnw:693-695
+### code chunk number 28: overview.Rnw:736-738
 ###################################################
 sc <- set.cor(y = 5:9,x=3:4,data=Thurstone,z=1:2)
 round(sc$residual,2)
 
 
 ###################################################
-### code chunk number 27: overview.Rnw:761-763
+### code chunk number 29: overview.Rnw:805-807
 ###################################################
 f3t <- fa(Thurstone,3,n.obs=213)
 f3t 
 
 
 ###################################################
-### code chunk number 28: overview.Rnw:784-787
+### code chunk number 30: overview.Rnw:828-831
 ###################################################
 f3 <- fa(Thurstone,3,n.obs = 213,fm="pa")
 f3o <- target.rot(f3)
@@ -214,130 +229,130 @@ f3o
 
 
 ###################################################
-### code chunk number 29: overview.Rnw:808-810
+### code chunk number 31: overview.Rnw:852-854
 ###################################################
 f3w <- fa(Thurstone,3,n.obs = 213,fm="wls")
 print(f3w,cut=0,digits=3)
 
 
 ###################################################
-### code chunk number 30: overview.Rnw:822-823
+### code chunk number 32: overview.Rnw:866-867
 ###################################################
 plot(f3t)
 
 
 ###################################################
-### code chunk number 31: overview.Rnw:835-836
+### code chunk number 33: overview.Rnw:879-880
 ###################################################
 fa.diagram(f3t)
 
 
 ###################################################
-### code chunk number 32: overview.Rnw:855-857
+### code chunk number 34: overview.Rnw:899-901
 ###################################################
 p3p <-principal(Thurstone,3,n.obs = 213,rotate="Promax")
 p3p
 
 
 ###################################################
-### code chunk number 33: overview.Rnw:876-878
+### code chunk number 35: overview.Rnw:920-922
 ###################################################
 om.h <- omega(Thurstone,n.obs=213,sl=FALSE)
 op <- par(mfrow=c(1,1))
 
 
 ###################################################
-### code chunk number 34: overview.Rnw:889-890
+### code chunk number 36: overview.Rnw:933-934
 ###################################################
 om <- omega(Thurstone,n.obs=213)
 
 
 ###################################################
-### code chunk number 35: overview.Rnw:923-925
+### code chunk number 37: overview.Rnw:967-969
 ###################################################
 data(bfi)
 ic <- iclust(bfi[1:25])
 
 
 ###################################################
-### code chunk number 36: overview.Rnw:937-938
+### code chunk number 38: overview.Rnw:981-982
 ###################################################
 summary(ic)  #show the results
 
 
 ###################################################
-### code chunk number 37: overview.Rnw:951-953
+### code chunk number 39: overview.Rnw:995-997
 ###################################################
 data(bfi)
 r.poly <- polychoric(bfi[1:25]) #the ... indicate the progress of the function
 
 
 ###################################################
-### code chunk number 38: overview.Rnw:966-968
+### code chunk number 40: overview.Rnw:1010-1012
 ###################################################
 ic.poly <- iclust(r.poly$rho,title="ICLUST using polychoric correlations")
 iclust.diagram(ic.poly) 
 
 
 ###################################################
-### code chunk number 39: overview.Rnw:979-981
+### code chunk number 41: overview.Rnw:1023-1025
 ###################################################
 ic.poly <- iclust(r.poly$rho,5,title="ICLUST using polychoric correlations for nclusters=5")
 iclust.diagram(ic.poly) 
 
 
 ###################################################
-### code chunk number 40: overview.Rnw:992-993
+### code chunk number 42: overview.Rnw:1036-1037
 ###################################################
 ic.poly <- iclust(r.poly$rho,beta.size=3,title="ICLUST beta.size=3")
 
 
 ###################################################
-### code chunk number 41: overview.Rnw:1005-1006
+### code chunk number 43: overview.Rnw:1049-1050
 ###################################################
 print(ic,cut=.3)
 
 
 ###################################################
-### code chunk number 42: overview.Rnw:1025-1027
+### code chunk number 44: overview.Rnw:1069-1071
 ###################################################
 fa(bfi[1:10],2,n.iter=20)
 
 
 
 ###################################################
-### code chunk number 43: overview.Rnw:1040-1042
+### code chunk number 45: overview.Rnw:1084-1086
 ###################################################
 f4 <- fa(bfi[1:25],4,fm="pa")
 factor.congruence(f4,ic)
 
 
 ###################################################
-### code chunk number 44: overview.Rnw:1051-1052
+### code chunk number 46: overview.Rnw:1095-1096
 ###################################################
 factor.congruence(list(f3t,f3o,om,p3p))
 
 
 ###################################################
-### code chunk number 45: overview.Rnw:1096-1097
+### code chunk number 47: overview.Rnw:1140-1141
 ###################################################
 vss <- vss(bfi[1:25],title="Very Simple Structure of a Big 5 inventory")
 
 
 ###################################################
-### code chunk number 46: overview.Rnw:1105-1106
+### code chunk number 48: overview.Rnw:1149-1150
 ###################################################
 vss
 
 
 ###################################################
-### code chunk number 47: overview.Rnw:1116-1117
+### code chunk number 49: overview.Rnw:1160-1161
 ###################################################
 fa.parallel(bfi[1:25],main="Parallel Analysis of a Big 5 inventory")
 
 
 ###################################################
-### code chunk number 48: overview.Rnw:1135-1140
+### code chunk number 50: overview.Rnw:1179-1184
 ###################################################
 v16 <- sim.item(16)
 s <- c(1,3,5,7,9,11,13,15)
@@ -347,7 +362,7 @@ fa.diagram(f2,fe=fe)
 
 
 ###################################################
-### code chunk number 49: overview.Rnw:1193-1197
+### code chunk number 51: overview.Rnw:1237-1241
 ###################################################
 set.seed(17)
 r9 <- sim.hierarchical(n=500,raw=TRUE)$observed
@@ -356,7 +371,7 @@ alpha(r9)
 
 
 ###################################################
-### code chunk number 50: overview.Rnw:1204-1207
+### code chunk number 52: overview.Rnw:1248-1251
 ###################################################
 
 alpha(attitude,keys=c("complaints","critical"))
@@ -364,45 +379,45 @@ alpha(attitude,keys=c("complaints","critical"))
 
 
 ###################################################
-### code chunk number 51: overview.Rnw:1214-1216
+### code chunk number 53: overview.Rnw:1258-1260
 ###################################################
 
 alpha(attitude)
 
 
 ###################################################
-### code chunk number 52: overview.Rnw:1223-1225
+### code chunk number 54: overview.Rnw:1267-1269
 ###################################################
 items <- sim.congeneric(N=500,short=FALSE,low=-2,high=2,categorical=TRUE) #500 responses to 4 discrete items
 alpha(items$observed)  #item response analysis of congeneric measures
 
 
 ###################################################
-### code chunk number 53: overview.Rnw:1278-1279
+### code chunk number 55: overview.Rnw:1322-1323
 ###################################################
 om.9 <- omega(r9,title="9 simulated variables")
 
 
 ###################################################
-### code chunk number 54: overview.Rnw:1290-1291
+### code chunk number 56: overview.Rnw:1334-1335
 ###################################################
 om.9
 
 
 ###################################################
-### code chunk number 55: overview.Rnw:1299-1300
+### code chunk number 57: overview.Rnw:1343-1344
 ###################################################
 omegaSem(r9,n.obs=500)
 
 
 ###################################################
-### code chunk number 56: overview.Rnw:1309-1310
+### code chunk number 58: overview.Rnw:1353-1354
 ###################################################
 splitHalf(r9)
 
 
 ###################################################
-### code chunk number 57: overview.Rnw:1332-1350
+### code chunk number 59: overview.Rnw:1376-1394
 ###################################################
 #the old way is by location-- specify the total number of items
 keys <- make.keys(nvars=28,list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10),
@@ -425,7 +440,7 @@ keys <- make.keys(bfi,keys.list) #specify the data file to be scored (bfi)
 
 
 ###################################################
-### code chunk number 58: overview.Rnw:1357-1361
+### code chunk number 60: overview.Rnw:1401-1405
 ###################################################
  keys.1<- make.keys(10,list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10)))
 keys.2 <- make.keys(15,list(Extraversion=c(-1,-2,3:5),Neuroticism=c(6:10),
@@ -434,14 +449,14 @@ keys.2 <- make.keys(15,list(Extraversion=c(-1,-2,3:5),Neuroticism=c(6:10),
 
 
 ###################################################
-### code chunk number 59: overview.Rnw:1371-1373
+### code chunk number 61: overview.Rnw:1415-1417
 ###################################################
  scores <- scoreItems(keys,bfi)
  scores
 
 
 ###################################################
-### code chunk number 60: scores
+### code chunk number 62: scores
 ###################################################
 png('scores.png')
 pairs.panels(scores$scores,pch='.',jiggle=TRUE)
@@ -449,7 +464,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 61: overview.Rnw:1399-1402
+### code chunk number 63: overview.Rnw:1443-1446
 ###################################################
 r.bfi <- cor(bfi,use="pairwise")
 scales <- scoreItems(keys,r.bfi)
@@ -457,7 +472,7 @@ summary(scales)
 
 
 ###################################################
-### code chunk number 62: overview.Rnw:1412-1418
+### code chunk number 64: overview.Rnw:1456-1462
 ###################################################
 data(iqitems)
 iq.keys <- c(4,4,4, 6,6,3,4,4,  5,2,2,4,  3,2,6,7)
@@ -468,7 +483,7 @@ describe(iq.tf)  #compare to previous results
 
 
 ###################################################
-### code chunk number 63: overview.Rnw:1436-1442
+### code chunk number 65: overview.Rnw:1480-1486
 ###################################################
 data(iqitems)
 iq.keys <- c(4,4,4, 6,6,3,4,4,  5,2,2,4,  3,2,6,7)
@@ -479,21 +494,21 @@ irt.responses(scores$scores,iqitems[1:4],breaks=11)
 
 
 ###################################################
-### code chunk number 64: overview.Rnw:1454-1456
+### code chunk number 66: overview.Rnw:1498-1500
 ###################################################
  m <- colMeans(bfi,na.rm=TRUE)
   item.lookup(scales$item.corrected[,1:3],m,dictionary=bfi.dictionary[1:2])
 
 
 ###################################################
-### code chunk number 65: overview.Rnw:1464-1466
+### code chunk number 67: overview.Rnw:1508-1510
 ###################################################
 data(bfi)
 best.scales(bfi,criteria=c("gender","education","age"),cut=.1,dictionary=bfi.dictionary[,1:3])
 
 
 ###################################################
-### code chunk number 66: overview.Rnw:1490-1494
+### code chunk number 68: overview.Rnw:1534-1538
 ###################################################
 set.seed(17)
 d9 <- sim.irt(9,1000,-2.5,2.5,mod="normal") #dichotomous items
@@ -502,7 +517,7 @@ test
 
 
 ###################################################
-### code chunk number 67: overview.Rnw:1501-1506
+### code chunk number 69: overview.Rnw:1545-1550
 ###################################################
 op <- par(mfrow=c(3,1))
 plot(test,type="ICC")
@@ -512,7 +527,7 @@ op <- par(mfrow=c(1,1))
 
 
 ###################################################
-### code chunk number 68: overview.Rnw:1517-1520
+### code chunk number 70: overview.Rnw:1561-1564
 ###################################################
 data(bfi)
 e.irt <- irt.fa(bfi[11:15])
@@ -520,43 +535,43 @@ e.irt
 
 
 ###################################################
-### code chunk number 69: overview.Rnw:1527-1528
+### code chunk number 71: overview.Rnw:1571-1572
 ###################################################
 e.info  <- plot(e.irt,type="IIC")
 
 
 ###################################################
-### code chunk number 70: overview.Rnw:1539-1540
+### code chunk number 72: overview.Rnw:1583-1584
 ###################################################
 print(e.info,sort=TRUE)
 
 
 ###################################################
-### code chunk number 71: overview.Rnw:1554-1555
+### code chunk number 73: overview.Rnw:1613-1614
 ###################################################
 iq.irt <- irt.fa(iq.tf)
 
 
 ###################################################
-### code chunk number 72: overview.Rnw:1567-1568
+### code chunk number 74: overview.Rnw:1626-1627
 ###################################################
 plot(iq.irt,type='test') 
 
 
 ###################################################
-### code chunk number 73: overview.Rnw:1579-1580
+### code chunk number 75: overview.Rnw:1638-1639
 ###################################################
 iq.irt 
 
 
 ###################################################
-### code chunk number 74: overview.Rnw:1586-1587
+### code chunk number 76: overview.Rnw:1645-1646
 ###################################################
 om <- omega(iq.irt$rho,4)
 
 
 ###################################################
-### code chunk number 75: overview.Rnw:1601-1615
+### code chunk number 77: overview.Rnw:1660-1674
 ###################################################
 v9 <- sim.irt(9,1000,-2.,2.,mod="normal") #dichotomous items
 items <- v9$items
@@ -575,14 +590,14 @@ colnames(scores.df) <- c("True theta","irt theta","total","fit","rasch","total",
 
 
 ###################################################
-### code chunk number 76: overview.Rnw:1624-1626
+### code chunk number 78: overview.Rnw:1683-1685
 ###################################################
  pairs.panels(scores.df,pch='.',gap=0)
  title('Comparing true theta for IRT, Rasch and  classically based scoring',line=3)
 
 
 ###################################################
-### code chunk number 77: overview.Rnw:1675-1679
+### code chunk number 79: overview.Rnw:1748-1752
 ###################################################
 
 C <- cov(sat.act,use="pairwise")
@@ -591,14 +606,14 @@ summary(model1)
 
 
 ###################################################
-### code chunk number 78: overview.Rnw:1682-1684
+### code chunk number 80: overview.Rnw:1755-1757
 ###################################################
 #compare with mat.regress
 set.cor(c(4:6),c(1:3),C, n.obs=700)
 
 
 ###################################################
-### code chunk number 79: overview.Rnw:1767-1791
+### code chunk number 81: overview.Rnw:1840-1864
 ###################################################
 xlim=c(0,10)
 ylim=c(0,10)
@@ -627,7 +642,7 @@ dia.curved.arrow(mr,lr$top)
 
 
 ###################################################
-### code chunk number 80: overview.Rnw:1902-1903
+### code chunk number 82: overview.Rnw:1975-1976
 ###################################################
 sessionInfo()
 
